@@ -5,5 +5,5 @@
 touch f
 test -e f || exit 1
 adddeny "${PWD}"
-unlink_static-0 -1,EPERM f
+unlink_static-0 -1,EPERM f || exit 1
 test -e sandbox.log -a -e f
